==> pycrossword_generator-0.2.0.tar.gz: pycrossword_generator-0.2.0/README.md <==
# Crossword Puzzle Generator

![PyPI - Version](https://img.shields.io/pypi/v/pycrossword-generator?labelColor=%232e343b&label=pypi%20package)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pycrossword-generator?labelColor=%232e343b)
![PyPI - License](https://img.shields.io/pypi/l/pycrossword-generator?labelColor=%232e343b)
[![Tests](https://github.com/fabelx/pycrossword/actions/workflows/tests.yml/badge.svg)](https://github.com/fabelx/pycrossword/actions/workflows/tests.yml)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pycrossword-generator?labelColor=%232e343b)
___

> ## Currently, in development
___

## About
`pycrossword-generator` is a powerful Python library and CLI tool designed for creating custom crossword puzzles.
___

## Installation
```bash
pip install pycrossword-generator
```
From source:
```bash
make install
```
or
```bash
pip install .
```
___

## Usage
> ### There are several other libraries, such as [pycrossword](https://pypi.org/project/pycrossword/) and [crossword-generator](https://pypi.org/project/crossword-generator/), which may cause conflicts if you are using them in your project.

See [documentation](https://github.com/fabelx/pycrossword/blob/main/docs/README.md) for more details.
___

### To-do
- [ ] Add support for user-specified dimensions of the crossword grid.
___

## License
`pycrossword-generator` is released under the MIT License.
See the [LICENSE](https://github.com/fabelx/pycrossword/blob/main/LICENSE) file for license information.

==> pycrossword_generator-0.3.0.tar.gz: pycrossword_generator-0.3.0/README.md <==
# Crossword Puzzle Generator

![PyPI - Version](https://img.shields.io/pypi/v/pycrossword-generator?labelColor=%232e343b&label=pypi%20package)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pycrossword-generator?labelColor=%232e343b)
![PyPI - License](https://img.shields.io/pypi/l/pycrossword-generator?labelColor=%232e343b)
[![Tests](https://github.com/fabelx/pycrossword/actions/workflows/tests.yml/badge.svg)](https://github.com/fabelx/pycrossword/actions/workflows/tests.yml)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pycrossword-generator?labelColor=%232e343b)
___

> ## Currently, in development
___

## About
`pycrossword-generator` is a powerful Python library and CLI tool designed for creating custom crossword puzzles.
___

## Installation
```bash
pip install pycrossword-generator
```
From source:
```bash
make install
```
or
```bash
pip install .
```
___

## Usage
> ### There are several other libraries, such as [pycrossword](https://pypi.org/project/pycrossword/) and [crossword-generator](https://pypi.org/project/crossword-generator/), which may cause conflicts if you are using them in your project.

See [documentation](https://github.com/fabelx/pycrossword/blob/main/docs/README.md) for more details.
___

### To-do
- [x] Add support for user-specified dimensions of the crossword grid.
___

## License
`pycrossword-generator` is released under the MIT License.
See the [LICENSE](https://github.com/fabelx/pycrossword/blob/main/LICENSE) file for license information.
